#
# spec file for package xerces-j2
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define cvs_version	2_11_0
Name:           xerces-j2
Version:        2.11.0
Release:        515.1
Summary:        Java XML parser
License:        Apache-2.0
Group:          Development/Libraries/Java
Url:            http://xml.apache.org/xerces2-j/
Source0:        http://www.eu.apache.org/dist/xerces/j/source/Xerces-J-src.%{version}.tar.gz
Source1:        http://www.eu.apache.org/dist/xerces/j/source/Xerces-J-tools.%{version}.tar.gz
Source2:        %{name}-version.sh
Source3:        %{name}-version.1
Source4:        %{name}-constants.sh
Source5:        %{name}-constants.1
# PATCH-FIX-UPSTREAM bnc#814241 XERCESJ-1616
Patch0:         arrays-doubling.patch
Patch1:         scan-pseudo-attribute.patch
Patch2:         xerces-2_11_0-jdk7.patch
BuildRequires:  dos2unix
BuildRequires:  java-devel >= 1.6
BuildRequires:  javapackages-tools
BuildRequires:  unzip
Requires(post): update-alternatives
Requires(pre):  update-alternatives
Provides:       jaxp_parser_impl
BuildArch:      noarch

%description
Welcome to the future! Xerces2 is the next generation of high
performance, fully compliant XML parsers in the Apache Xerces family.
This new version of Xerces introduces the Xerces Native Interface
(XNI), a complete framework for building parser components and
configurations that is extremely modular and easy to program.

The Apache Xerces2 parser is the reference implementation of XNI but
other parser components, configurations, and parsers can be written
using the Xerces Native Interface. For complete design and
implementation documents, refer to the XNI Manual.

Xerces 2 is a fully conforming XML Schema processor. For more
information, refer to the XML Schema page.

Xerces 2 also provides a partial implementation of Document Object
Model Level 3 Core, Load and Save and Abstract Schemas [deprecated]
Working Drafts. For more information, refer to the DOM Level 3
Implementation page.

%package        demo
Summary:        Demonstration and sample files for xerces-j2
Group:          Development/Libraries/Java
Requires:       %{name} = %{version}

%description    demo
Welcome to the future! Xerces2 is the next generation of high
performance, fully compliant XML parsers in the Apache Xerces family.
This new version of Xerces introduces the Xerces Native Interface
(XNI), a complete framework for building parser components and
configurations that is extremely modular and easy to program.

The Apache Xerces2 parser is the reference implementation of XNI but
other parser components, configurations, and parsers can be written
using the Xerces Native Interface. For complete design and
implementation documents, refer to the XNI Manual.

Xerces 2 is a fully conforming XML Schema processor. For more
information, refer to the XML Schema page.

Xerces 2 also provides a partial implementation of Document Object
Model Level 3 Core, Load and Save and Abstract Schemas [deprecated]
Working Drafts. For more information, refer to the DOM Level 3
Implementation page.

This package contains demonstration and sample files for Xerces2.

%package        scripts
Summary:        Additional utility scripts for xerces-j2
Group:          Development/Libraries/Java
Requires:       %{name} = %{version}

%description    scripts
Welcome to the future! Xerces2 is the next generation of high
performance, fully compliant XML parsers in the Apache Xerces family.
This new version of Xerces introduces the Xerces Native Interface
(XNI), a complete framework for building parser components and
configurations that is extremely modular and easy to program.

The Apache Xerces2 parser is the reference implementation of XNI but
other parser components, configurations, and parsers can be written
using the Xerces Native Interface. For complete design and
implementation documents, refer to the XNI Manual.

Xerces 2 is a fully conforming XML Schema processor. For more
information, refer to the XML Schema page.

Xerces 2 also provides a partial implementation of Document Object
Model Level 3 Core, Load and Save and Abstract Schemas [deprecated]
Working Drafts. For more information, refer to the DOM Level 3
Implementation page.

This package contains additional utility scripts for Xerces2.

%package        xml-resolver
Summary:        Resolver subproject of xml-commons
Group:          Development/Libraries/Java
Requires(post): update-alternatives
Requires(pre):  update-alternatives
Provides:       xml-commons-resolver

%description    xml-resolver
xml-commons is focused on common code and guidelines for xml projects.
The first focus will be to organize and have common packaging for the
various externally-defined standards code relating to XML - things like
the DOM, SAX, and JAXP interfaces.

This package contains the resolver subproject of xml-commons.

%package        xml-apis
Summary:        APIs subproject of xml-commons
Group:          Development/Libraries/Java
Requires(post): update-alternatives
Requires(pre):  update-alternatives
Provides:       xml-commons-apis

%description    xml-apis
xml-commons is focused on common code and guidelines for xml projects.
Its first focus will be to organize and have common packaging for the
various externally-defined standards code relating to XML - things like
the DOM, SAX, and JAXP interfaces. As the xml-commons community forms,
we also hope to serve as a holding area for other common xml-related
utilities and code, and to help promulgate common packaging, testing,
documentation, and other guidelines across all xml.apache.org
subprojects.

This package contains the APIs subproject of xml-commons.

%prep
%setup -q -n xerces-%{cvs_version}
%setup -q -T -a 1 -D -n xerces-%{cvs_version}
%setup -q -T -D -n xerces-%{cvs_version}

find -type f -print |xargs -i dos2unix {}
%patch0 -p1
%patch1 -p1
%patch2 -p1

echo 'javac.target=1.6' > build.properties
echo 'javac.source=1.6' >> build.properties

sed -i 's/\r//' LICENSE README NOTICE build.sh

%build
## this uses the ant.jar provided by the xerces packages. Tough luck,
# jpackage bootstrap has to start somewhere. It is not installed,
# though.
export GC_MAXIMUM_HEAP_SIZE="134217728"
export CLASSPATH=$CLASSPATH:$(build-classpath antlr-bootstrap)
sh build.sh jars
#ant tests test

%install
# jars
mkdir -p %{buildroot}%{_javadir}
cp -p build/xercesImpl.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
cp -p build/resolver.jar   %{buildroot}%{_javadir}/%{name}-%{version}-xml-resolver.jar
cp -p build/xml-apis.jar   %{buildroot}%{_javadir}/%{name}-%{version}-xml-apis.jar
(cd %{buildroot}%{_javadir} && for jar in *-%{version}*.jar; do ln -sf ${jar} `echo $jar| sed "s|-%{version}||g"`; done)
# scripts
mkdir -p %{buildroot}%{_bindir}
install -p -m 755 %{SOURCE2} %{buildroot}%{_bindir}/%{name}-version
install -p -m 755 %{SOURCE4} %{buildroot}%{_bindir}/%{name}-constants
# mans
install -d -m 755 %{buildroot}%{_mandir}/man1
install -p -m 644 %{SOURCE3} %{buildroot}%{_mandir}/man1
install -p -m 644 %{SOURCE5} %{buildroot}%{_mandir}/man1
# demo
mkdir -p %{buildroot}%{_datadir}/%{name}
cp -p build/xercesSamples.jar \
  %{buildroot}%{_datadir}/%{name}/%{name}-samples.jar
cp -pr data %{buildroot}%{_datadir}/%{name}

# alternatives
mkdir -p %{buildroot}%{_sysconfdir}/alternatives/
ln -sf %{_sysconfdir}/alternatives/jaxp_parser_impl.jar %{buildroot}%{_javadir}/jaxp_parser_impl.jar
ln -sf %{_sysconfdir}/alternatives/xml-commons-apis.jar %{buildroot}%{_javadir}/xml-commons-apis.jar
ln -sf %{_sysconfdir}/alternatives/xml-commons-resolver.jar %{buildroot}%{_javadir}/xml-commons-resolver.jar

%post
%{_sbindir}/update-alternatives --install %{_javadir}/jaxp_parser_impl.jar jaxp_parser_impl  %{_javadir}/%{name}.jar 23
%{_sbindir}/update-alternatives --auto jaxp_parser_impl

%post xml-apis
%{_sbindir}/update-alternatives --install %{_javadir}/xml-commons-apis.jar         xml-commons-apis          %{_javadir}/%{name}-xml-apis.jar 1
%{_sbindir}/update-alternatives --auto xml-commons-apis

%post xml-resolver
%{_sbindir}/update-alternatives --install %{_javadir}/xml-commons-resolver.jar     xml-commons-resolver      %{_javadir}/%{name}-xml-resolver.jar 1
%{_sbindir}/update-alternatives --auto xml-commons-resolver

%preun
if [ $1 = 0 ] ; then
  %{_sbindir}/update-alternatives --remove jaxp_parser_impl        %{_javadir}/%{name}.jar
fi

%preun xml-apis
if [ $1 = 0 ] ; then
  %{_sbindir}/update-alternatives --remove xml-commons-apis        %{_javadir}/%{name}-xml-apis.jar
fi

%preun xml-resolver
if [ $1 = 0 ] ; then
  %{_sbindir}/update-alternatives --remove xml-commons-resolver    %{_javadir}/%{name}-xml-commons-resolver.jar
fi

%files
%doc LICENSE README
%{_javadir}/%{name}-%{version}.jar
%{_javadir}/%{name}.jar
%{_javadir}/jaxp_parser_impl.jar
%ghost %{_sysconfdir}/alternatives/jaxp_parser_impl.jar

%files xml-apis
%{_javadir}/%{name}-%{version}-xml-apis.jar
%{_javadir}/%{name}-xml-apis.jar
%{_javadir}/xml-commons-apis.jar
%ghost %{_sysconfdir}/alternatives/xml-commons-apis.jar

%files xml-resolver
%{_javadir}/%{name}-%{version}-xml-resolver.jar
%{_javadir}/%{name}-xml-resolver.jar
%{_javadir}/xml-commons-resolver.jar
%ghost %{_sysconfdir}/alternatives/xml-commons-resolver.jar

%files demo
%{_datadir}/%{name}

%files scripts
%{_bindir}/*
%{_mandir}/man1/*

%changelog
* Tue Oct  3 2017 fstrba@suse.com
- Added patch:
  * xerces-2_11_0-jdk7.patch
    + Dummy implementation of the getContentDocument() in common
    DOM API, in order to be able to build with jdk >= 1.6
- Specify java source and target level 1.6 and don't depend on gcj
* Fri May 19 2017 tchvatal@suse.com
- BuildIgnore more main java versions to stick to gcj
* Thu Feb 11 2016 tchvatal@suse.com
- Add patches for bnc#814241 upstream#1616
  * arrays-doubling.patch
  * scan-pseudo-attribute.patch
* Mon Jul 21 2014 tchvatal@suse.com
- Fixup man page permissions
* Mon Jul 21 2014 tchvatal@suse.com
- Sort out update-alternatives
* Fri Jun  6 2014 tchvatal@suse.com
- Version bump to 2.11.0:
  * This release expands on Xerces' experimental support for XML
    Schema 1.1 by providing implementations for the simplified
    complex type restriction rules (also known as subsumption),
    xs:override and a few other XML Schema 1.1 features. This
    release also introduces experimental support for XML Schema
    Component Designators (SCD). It fixes several bugs which were
    present in Xerces-J 2.10.0 and also includes a few other minor
    enhancements.
  * As of this release, Xerces and Xalan now share a common
    serialization codebase. The DOM Level 3 serialization support
    which was in Xerces was migrated into the Xalan serializer and
    Xerces' native serializer was deprecated. In this release we
    also upgraded the xml-commons resolver to v1.2 (which provides
    support for OASIS XML Catalogs v1.1), introduced a few minor
    features and fixed several bugs.
- Obsoleted patches no longer needed:
  * xerces-j2-parsing.patch
  * xerces-j2-2.8.1_new_unsupported_dom_methods.patch
  * xerces-build.patch
  * xerces-j2-gcj-switch-constants-bug.patch
  * java150_build.patch
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Fri Aug 23 2013 mvyskocil@suse.com
- drop javadoc packages
- drop antlr-bootstrap from BR as javadoc is not built
* Fri Jan 11 2013 mvyskocil@suse.com
- removed the -boostrap package
* Fri Sep 16 2011 andrea.turrini@gmail.com
- fixed typos in xerces-j2.spec
* Mon Mar 14 2011 mvyskocil@suse.cz
- build ignore openjdk
* Tue Sep 21 2010 mvyskocil@suse.cz
- use antlr-bootstrap for javadoc build
* Mon Sep 13 2010 mvyskocil@suse.cz
- remove unecessary xerces-j2-build.patch
* Thu Sep  2 2010 mvyskocil@suse.cz
- ignore antlr(-java) to reduce build cycles
* Mon Aug 17 2009 mvyskocil@suse.cz
- fixed bnc#530717: VUL-0: xerces-j2: XML parsing vulnerability
- Removed non used patch xerces-build.patch
- Fixed some rpmlint warnings and errors
- Removed javadoc postinstall scripts
- Removed %%%%release from subpackages requires
* Wed Nov 12 2008 mvyskocil@suse.cz
- use gcj for build as this version is not compatible with INM Java6
- added a jpackage-utils to BuildRequires
* Fri Feb 29 2008 coolo@suse.de
- adding prereq for xml-apis and xml-resolver
* Wed Jan 23 2008 prusnak@suse.cz
- removed comma between symbols in PreReq
* Wed May  2 2007 dbornkessel@suse.de
- added unzip to BuildRequires
* Tue Jan 23 2007 dbornkessel@suse.de
- added dummy methods for not yet supported new dom methods
* Tue Jan 16 2007 dbornkessel@suse.de
- created sub-packages xml-apis and xml-resolver to avoid Bug #232127
* Wed Nov 15 2006 dbornkessel@suse.de
- Changed
    PreReq: /usr/sbin/update-alternatives
  to
    PreReq: update-alternatives
* Fri Sep 22 2006 dbornkessel@suse.de
- update to 2.8.1
- added source="1.4" target="1.4" to [x]javac & javadoc ant tasks
* Mon Jan 30 2006 dbornkessel@suse.de
- changed update alternatives prios
- corrected update-alternatives name for 'xml-commons-resolver'
* Fri Jan 27 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 24 2006 dbornkessel@suse.de
- added missing jar file (xml-apis & resolver)
- added xml-apis and resolver to alternative system, so they can be
  interchanged with xml-commons-apis and commons-resolver
* Wed Jan 18 2006 dbornkessel@suse.de
- Update to version 2.7.1
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Thu Sep 16 2004 skh@suse.de
- Fix prerequires
* Thu Sep  2 2004 skh@suse.de
- Initial package created with version 2.6.2 (JPackage 1.5)
